{ pkgs, ... }: {
  imports = [
    <home-manager/nixos>
    ./hardware-configuration.nix
    ./packages.nix
    ./home.nix
    ./user.nix
    ./services.nix
    ./programs.nix
    ./disks.nix
    ./defaults.nix
  ];

  nix.settings = {
    substituters = [ "https://helix.cachix.org" ];
    trusted-public-keys =
      [ "helix.cachix.org-1:ejp9KQpR1FBI2onstMQ34yogDm4OgU2ru6lIwPvuCVs=" ];

  };
  nix.settings.experimental-features = [ "nix-command" "flakes" ];

  # kernel
  boot.kernelPackages = pkgs.linuxPackages_latest;

  # Bootloader.
  boot.loader.systemd-boot.enable = true;
  boot.loader.efi.canTouchEfiVariables = true;
  boot.loader.efi.efiSysMountPoint = "/boot/efi";

  boot.supportedFilesystems = [ "ntfs" ];

  hardware = {
    opengl = {
      enable = true;
      driSupport = true;
      driSupport32Bit = true;
      extraPackages32 = with pkgs; [
        intel-media-driver
        vaapiIntel
        vaapiVdpau
        libvdpau-va-gl
      ];
      extraPackages = with pkgs; [
        intel-media-driver
        vaapiIntel
        vaapiVdpau
        libvdpau-va-gl
        mesa.drivers
      ];
    };
  };

  programs.fish.enable = true;
  programs.fish.promptInit = ''
    any-nix-shell fish --info-right | source
  '';

  xdg.portal = {
    enable = true;
    wlr.enable = true;
  };

  # hostname
  networking.hostName = "bat"; # Define your hostname.

  # Enable networking
  networking.networkmanager.enable = true;

  # Set your time zone.
  time.timeZone = "Europe/Berlin";

  # Select internationalisation properties.
  i18n.defaultLocale = "en_US.utf8";

  i18n.extraLocaleSettings = {
    LC_ADDRESS = "de_DE.utf8";
    LC_IDENTIFICATION = "de_DE.utf8";
    LC_MEASUREMENT = "de_DE.utf8";
    LC_MONETARY = "de_DE.utf8";
    LC_NAME = "de_DE.utf8";
    LC_NUMERIC = "de_DE.utf8";
    LC_PAPER = "de_DE.utf8";
    LC_TELEPHONE = "de_DE.utf8";
    LC_TIME = "de_DE.utf8";
  };

  # xserver options
  services.xserver = {
    wacom.enable = true;
    displayManager = {
      startx.enable = true;
      defaultSession = "none+i3";
    };
    enable = true;
    layout = "us";
    xkbVariant = "alt-intl";

    windowManager.i3 = {
      package = pkgs.i3-gaps;
      enable = true;
      extraPackages = with pkgs; [
        autotiling
        brightnessctl
        xorg.xev
        dunst
        libnotify
        python311
        i3status-rust
        find-cursor
      ];
    };

    libinput = {
      enable = true;
      mouse = {
        accelProfile = "flat";
        accelSpeed = "1.0";
      };
    };
  };

  # Configure console keymap
  console = {
    # earlySetup = true;
    keyMap = "us";
    # font = config.font.mono;
  };

  # Enable CUPS to print documents.
  # services.printing.enable = true;

  programs.seahorse.enable = true;

  # Enable sound with pipewire.
  sound.enable = true;
  hardware.pulseaudio.enable = false;

  # enable bluetooth
  hardware.bluetooth.enable = true;

  security.rtkit.enable = true;
  security.please.enable = true;

  services.pipewire = {
    enable = true;
    alsa.enable = true;
    alsa.support32Bit = true;
    pulse.enable = true;
    wireplumber.enable = true;
    jack.enable = true;

    # use the example session manager (no others are packaged yet so this is enabled by default,
    # no need to redefine it in your config for now)
    #media-session.enable = true;
  };

  # Allow unfree packages
  nixpkgs.config.allowUnfree = true;

  # Some programs need SUID wrappers, can be configured further or are
  # started in user sessions.
  # programs.mtr.enable = true;
  # programs.gnupg.agent = {
  #   enable = true;
  #   enableSSHSupport = true;
  # };

  # vim
  environment.variables.EDITOR = "nvim";
  programs.neovim.enable = true;
  programs.neovim.viAlias = true;
  programs.neovim.vimAlias = true;

  # wireguard settings
  networking.firewall = {
    allowedUDPPorts = [ 51820 ];
    enable = true;
  };

  # This value determines the NixOS release from which the default
  # settings for stateful data, like file locations and database versions
  # on your system were taken. It‘s perfectly fine and recommended to leave
  # this value at the release version of the first install of this system.
  # Before changing this value read the documentation for this option
  # (e.g. man configuration.nix or on https://nixos.org/nixos/options.html).
  system.stateVersion = "22.05"; # Did you read the comment?

  programs.dconf.enable = true;

  # vars
  environment.variables = { MOZ_USE_XINPUT2 = "DEFAULT=1"; };

  nixpkgs.config.permittedInsecurePackages = [ "python-2.7.18.6" ];
}
